---
title: Unwrappables and Constraints
---

## Basic classes and functions

::: klax.Unwrappable
    options:
        members:
            - __init__
            - __call__
::: klax.unwrap
::: klax.contains_unwrappables
::: klax.Constraint
    options:
        members:
            - __init__
            - __call__
::: klax.apply
::: klax.contains_constraints
::: klax.finalize

---

## Unwrappables

::: klax.Parameterize
    options:
        members:
            - __init__
            - __call__
::: klax.NonTrainable
    options:
        members:
            - __init__
            - __call__
::: klax.non_trainable
::: klax.Symmetric
    options:
        members:
            - __init__
            - __call__
::: klax.SkewSymmetric
    options:
        members:
            - __init__
            - __call__

---

## Constraints

::: klax.NonNegative
    options:
        members:
            - __init__
            - __call__

